@@ -20,8 +20,6 @@ import yaml
 # Only permit the template alias versions
 # The current template version should be the last element
 valid_heat_template_versions = [
-  'ocata',
-  'pike',
   'queens',
 ]
 current_heat_template_version = valid_heat_template_versions[-1]
@@ -53,7 +51,8 @@ OPTIONAL_DOCKER_SECTIONS = ['docker_puppet_tasks', 'upgrade_tasks',
                             'kolla_config', 'global_config_settings',
                             'logging_source', 'logging_groups',
                             'external_deploy_tasks', 'external_post_deploy_tasks',
-                            'docker_config_scripts', 'step_config']
+                            'docker_config_scripts', 'step_config',
+                            'monitoring_subscription']
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
                           'fast_forward_upgrade_tasks',
@@ -155,6 +154,7 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
 PREFERRED_CAMEL_CASE = {
     'ec2api': 'Ec2Api',
     'haproxy': 'HAProxy',
+    'metrics-qdr': 'MetricsQdr'
 }
 
 # Overrides for docker/puppet validation
@@ -349,7 +349,7 @@ def validate_controller_no_ceph_role(filename, tpl):
                 return 1
     return 0
 
-def validate_with_compute_role_services(role_filename, role_tpl, exclude_service):
+def validate_with_compute_role_services(role_filename, role_tpl, exclude_service=()):
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     cmpt_tpl = yaml.load(open(cmpt_filename).read())
@@ -363,8 +363,56 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
               'ServicesDefault in roles/Compute.yaml'.format(role_filename,
               ', '.join(missing_services)))
         return 1
+
+    cmpt_us = cmpt_tpl[0].get('update_serial', None)
+    tpl_us = role_tpl[0].get('update_serial', None)
+
+    if 'OS::TripleO::Services::CephOSD' in role_services:
+        if tpl_us not in (None, 1):
+            print('ERROR: update_serial in {0} ({1}) '
+                  'is should be 1 as it includes CephOSD'.format(
+                      role_filename,
+                      tpl_us,
+                      cmpt_us))
+            return 1
+    elif cmpt_us is not None and tpl_us != cmpt_us:
+        print('ERROR: update_serial in {0} ({1}) '
+              'does not match roles/Compute.yaml {2}'.format(
+                  role_filename,
+                  tpl_us,
+                  cmpt_us))
+        return 1
+
     return 0
 
+def validate_multiarch_compute_roles(role_filename, role_tpl):
+    errors = 0
+    roles_dir = os.path.dirname(role_filename)
+    compute_services = set(role_tpl[0].get('ServicesDefault', []))
+    compute_networks = set(role_tpl[0].get('networks', []))
+
+    for arch in ['ppc64le']:
+        arch_filename = os.path.join(roles_dir,
+                                     'Compute%s.yaml' % (arch.upper()))
+        with open(arch_filename) as f:
+            arch_tpl = yaml.safe_load(f)
+
+        arch_services = set(arch_tpl[0].get('ServicesDefault', []))
+        if compute_services != arch_services:
+            print('ERROR ServicesDefault in %s and %s do not match' %
+                  (role_filename, arch_filename))
+            print('ERROR problems with: %s' % (','.join(compute_services.symmetric_difference(arch_services))))
+            errors = 1
+
+        arch_networks = set(arch_tpl[0].get('networks', []))
+        if compute_networks != arch_networks:
+            print('ERROR networks in %s and %s do not match' %
+                  (role_filename, arch_filename))
+            print('ERROR problems with: %s' % (','.join(compute_networks.symmetric_difference(arch_networks))))
+            errors = 1
+
+    return errors
+
 
 def search(item, check_item, check_key):
     if check_item(item):
@@ -775,6 +823,13 @@ def validate(filename, param_map):
         if filename.startswith('./roles/ControllerNoCeph.yaml'):
             retval = validate_controller_no_ceph_role(filename, tpl)
 
+        if filename in ('./roles/ComputeLocalEphemeral.yaml',
+                        './roles/ComputeRBDEphemeral.yaml'):
+            retval |= validate_with_compute_role_services(filename, tpl)
+
+        if filename == './roles/Compute.yaml':
+            retval |= validate_multiarch_compute_roles(filename, tpl)
+
         if filename.startswith('./network_data_'):
             retval = validate_network_data_file(filename)
 
